@@ -924,8 +924,9 @@ class HastexoXBlock(XBlock,
                     status = result.result
                     score = Score(raw_earned=status['pass'],
                                   raw_possible=status['total'])
+                    self.set_score(score)
                     # A publish event is necessary for calculating grades
-                    self.publish_grade(score)
+                    self.publish_grade()
 
                 else:
                     status = {
@@ -973,6 +974,12 @@ class HastexoXBlock(XBlock,
         """
         return self.weight
 
+    def has_submitted_answer(self):
+        """
+        Returns True if the problem has been answered by the runtime user.
+        """
+        return self.score is not None
+
     def set_score(self, score):
         """
         Persist a score to the XBlock.
@@ -992,10 +999,37 @@ class HastexoXBlock(XBlock,
             'raw_possible': score.raw_possible
         }
 
-    def publish_grade(self, score):
+    def get_score(self):
+        """
+        Return a raw score already persisted on the XBlock.  Should not
+        perform new calculations.
+        Returns:
+            Score(raw_earned=float, raw_possible=float)
+        """
+        if not self.score:
+            logger.warning("No score is earned for this block yet")
+        else:
+            return Score(
+                raw_earned=self.score.get('raw_earned'),
+                raw_possible=self.score.get('raw_possible'))
+
+    def calculate_score(self):
+        """
+        Calculate a new raw score based on the state of the problem.
+        This method should not modify the state of the XBlock.
+        Returns:
+            Score(raw_earned=float, raw_possible=float)
+        """
+        # Nothing to calculate here
+        # This will be called only if self.has_submitted_answer() returns True
+        # Just return the stored value
+        return self.get_score()
+
+    def publish_grade(self):
         """
         Publish a grade to the runtime.
         """
+        score = self.get_score()
         self._publish_grade(score=score)
 
     @staticmethod
